@@ -6,5 +6,7 @@ class ModelNotFoundHandler:
         self.application = application
 
     def handle(self, exception):
-        masonite_exception = ModelNotFoundException()
+        masonite_exception = ModelNotFoundException(
+            "No record found with the given primary key"
+        )
         self.application.make("exception_handler").handle(masonite_exception)
