@@ -1,12 +1,12 @@
-from email.mime import application
 import time
 
 from ..request import Request
-from ..response import Response
 from .Provider import Provider
 
+from ..configuration import config
 from ..presets.PresetsCapsule import PresetsCapsule
 from ..presets import Tailwind, Vue, React, Bootstrap
+from ..cors import Cors
 
 
 class FrameworkProvider(Provider):
@@ -22,7 +22,25 @@ class FrameworkProvider(Provider):
         presets.add(React())
         self.application.bind("presets", presets)
 
+        # @M5 remove this and add SecurityProvider in default project
+        # @M5 old projects won't have securiy options so put default here. remove this for M5.
+        options = config("security.cors")
+        if not options:
+            options = {
+                "paths": ["api/*"],
+                "allowed_methods": ["*"],
+                "allowed_origins": ["*"],
+                "allowed_headers": ["*"],
+                "exposed_headers": [],
+                "max_age": None,
+                "supports_credentials": False,
+            }
+        cors = Cors(self.application).set_options(options)
+        self.application.bind("cors", cors)
+
     def boot(self):
+        from ..response import Response
+
         request = Request(self.application.make("environ"))
         request.app = self.application
         if self.application.has("activate.subdomains") and self.application.make(
