@@ -31,7 +31,7 @@ class Response:
 
     def json(self, payload: Any, status: int = 200) -> bytes:
         """Set the response as a JSON response."""
-        self.content = bytes(json.dumps(payload), "utf-8")
+        self.content = bytes(json.dumps(payload, ensure_ascii=False), "utf-8")
         self.make_headers(content_type="application/json; charset=utf-8")
         self.status(status)
 
@@ -57,8 +57,13 @@ class Response:
 
         return self.header_bag.add(Header(name, value))
 
+    def with_headers(self, headers: dict) -> "Response":
+        """Add headers dictionary to response headers."""
+        for name, value in headers.items():
+            self.header_bag.add(Header(name, str(value)))
+        return self
+
     def get_headers(self) -> list:
-        """Get all response headers."""
         return self.header_bag.render()
 
     def cookie(self, name: str, value: str = None, **options) -> "None|str":
@@ -120,7 +125,7 @@ class Response:
     def converted_data(self) -> "str|bytes":
         """Get the response content as string or bytes so that the WSGI server handles it."""
         if isinstance(self.data(), (dict, list)):
-            return json.dumps(self.data())
+            return json.dumps(self.data(), ensure_ascii=False)
         else:
             return self.data()
 
