@@ -3,6 +3,8 @@ import re
 import os
 import mimetypes
 
+from ..filesystem import UploadedFile
+
 from .RuleEnclosure import RuleEnclosure
 from .MessageBag import MessageBag
 from ..utils.structures import data_get
@@ -163,6 +165,17 @@ class one_of(BaseValidation):
         return "The {} is not required.".format(text)
 
 
+class boolean(BaseValidation):
+    def passes(self, attribute, key, dictionary):
+        return (attribute in [True, False, 0, 1, '0', '1'])
+
+    def message(self, attribute):
+        return "The {} must be a boolean.".format(attribute)
+
+    def negated_message(self, attribute):
+        return "The {} must not be a boolean.".format(attribute)
+
+
 class accepted(BaseValidation):
     def passes(self, attribute, key, dictionary):
         return (
@@ -377,6 +390,39 @@ class exists_in_db(BaseValidation):
         )
 
 
+class not_exists_in_db(BaseValidation):
+    """A record with field equal to the given value should exists in the table/model specified."""
+
+    def __init__(
+        self,
+        validations,
+        table_or_model,
+        column=None,
+        connection="default",
+        messages={},
+        raises={},
+    ):
+        super().__init__(validations, messages=messages, raises=raises)
+        self.connection = config("database.db").get_query_builder(connection)
+        self.column = column
+        self.table, self.model = resolve_model_or_table(table_or_model)
+
+    def passes(self, attribute, key, dictionary):
+        column = key if not self.column else self.column
+        count = self.connection.table(self.table).where(column, attribute).count()
+        return count == 0
+
+    def message(self, attribute):
+        return "A record already exists in table {} with the same {}".format(
+            self.table, attribute
+        )
+
+    def negated_message(self, attribute):
+        return "No record found in table {} with the same {}".format(
+            self.table, attribute
+        )
+
+
 class unique_in_db(BaseValidation):
     """No record should exist for the field under validation within the given table/model."""
 
@@ -438,10 +484,10 @@ class numeric(BaseValidation):
     def passes(self, attribute, key, dictionary):
         if isinstance(attribute, list):
             for value in attribute:
-                if not str(value).isdigit():
+                if not str(value).replace(".", "", 1).isdigit():
                     return False
         else:
-            return str(attribute).isdigit()
+            return str(attribute).replace(".", "", 1).isdigit()
 
         return True
 
@@ -611,7 +657,7 @@ class greater_than(BaseValidation):
         self.value = value
 
     def passes(self, attribute, key, dictionary):
-        return attribute > self.value
+        return int(attribute) > int(self.value)
 
     def message(self, attribute):
         return "The {} must be greater than {}.".format(attribute, self.value)
@@ -641,8 +687,10 @@ class strong(BaseValidation):
         validations,
         length=8,
         uppercase=2,
+        lowercase=2,
         numbers=2,
         special=2,
+        special_chars=None,
         breach=False,
         messages={},
         raises={},
@@ -650,11 +698,14 @@ class strong(BaseValidation):
         super().__init__(validations, messages=messages, raises=raises)
         self.length = length
         self.uppercase = uppercase
+        self.lowercase = lowercase
         self.numbers = numbers
         self.special = special
+        self.special_chars = special_chars
         self.breach = breach
         self.length_check = True
         self.uppercase_check = True
+        self.lowercase_check = True
         self.numbers_check = True
         self.special_check = True
         self.breach_check = True
@@ -676,6 +727,16 @@ class strong(BaseValidation):
                 self.uppercase_check = False
                 all_clear = False
 
+        if self.lowercase != 0:
+            lowercase = 0
+            for letter in attribute:
+                if letter.islower():
+                    lowercase += 1
+
+            if lowercase < self.lowercase:
+                self.lowercase_check = False
+                all_clear = False
+
         if self.numbers != 0:
             numbers = 0
             for letter in attribute:
@@ -700,7 +761,10 @@ class strong(BaseValidation):
                 all_clear = False
 
         if self.special != 0:
-            if len(re.findall("[^A-Za-z0-9]", attribute)) < self.special:
+            special_chars = "[^A-Za-z0-9]"
+            if self.special_chars:
+                special_chars = f"[{self.special_chars}]"
+            if len(re.findall(special_chars, attribute)) < self.special:
                 self.special_check = False
                 all_clear = False
 
@@ -722,10 +786,18 @@ class strong(BaseValidation):
                 )
             )
 
-        if not self.special_check:
+        if not self.lowercase_check:
             message.append(
-                "The {} field must have {} special characters".format(
-                    attribute, self.special
+                "The {} field must have {} lowercase letters".format(
+                    attribute, self.lowercase
+                )
+            )
+
+        if not self.special_check:
+            valid_chars = self.special_chars or "!@#$%^&*()_+"
+            message.append(
+                "The {} field must contain at least {} of these characters: '{}'".format(
+                    attribute, self.special, valid_chars
                 )
             )
 
@@ -830,7 +902,7 @@ class json(BaseValidation):
 
 class phone(BaseValidation):
     def __init__(self, *rules, pattern="123-456-7890", messages={}, raises={}):
-        super().__init__(rules, messages={}, raises={})
+        super().__init__(rules, messages=messages, raises=raises)
         # 123-456-7890
         # (123)456-7890
         self.pattern = pattern
@@ -898,16 +970,24 @@ class BaseFileValidation(BaseValidation):
         self.all_clear = True
 
     def passes(self, attribute, key, dictionary):
-        if not os.path.isfile(attribute):
-            self.file_check = False
-            return False
+        # Here we can validate on a filepath or an uploaded file (from request)
+        if isinstance(attribute, UploadedFile):
+            filepath = attribute.name
+            file_size = attribute.size
+        else:
+            filepath = attribute
+            if not os.path.isfile(filepath):
+                self.file_check = False
+                return False
+            file_size = os.path.getsize(filepath)
+        # validate size
         if self.size:
-            file_size = os.path.getsize(attribute)
             if file_size > self.size:
                 self.size_check = False
                 self.all_clear = False
+        # validate extension
         if self.allowed_extensions:
-            mimetype, encoding = mimetypes.guess_type(attribute)
+            mimetype, encoding = mimetypes.guess_type(filepath)
             if mimetype not in self.allowed_mimetypes:
                 self.mimes_check = False
                 self.all_clear = False
@@ -1339,6 +1419,7 @@ class ValidationFactory:
     def __init__(self):
         self.register(
             accepted,
+            boolean,
             active_domain,
             after_today,
             before_today,
@@ -1352,6 +1433,7 @@ class ValidationFactory:
             email,
             exists,
             exists_in_db,
+            not_exists_in_db,
             file,
             greater_than,
             image,
